@@ -153,7 +153,7 @@ void InfoTree::parseInfoDirFile( const QString &infoDirFileName )
   }
   infoDirFile.close();
 
-  for ( InfoCategoryItem *item : qAsConst(alphabSections) ) {
+  for ( InfoCategoryItem *item : std::as_const(alphabSections) ) {
     item->sortChildren( 0, Qt::AscendingOrder );
   }
   m_alphabItem->sortChildren( 0, Qt::AscendingOrder );
@@ -163,3 +163,4 @@ void InfoTree::parseInfoDirFile( const QString &infoDirFileName )
 #include "moc_infotree.cpp"
 
 // vim:ts=2:sw=2:et
+
